#
# spec file for package deja-dup
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           deja-dup
Version:        15.5
Release:        1.12
License:        GPLv3+
Summary:        Simple backup tool and frontend for duplicity
Url:            https://launchpad.net/deja-dup
Group:          Productivity/Archiving/Backup
Source0:        %{name}-%{version}.tar.bz2
# PATCH-MISSING-TAG -- See http://wiki.opensuse.org/Packaging/Patches
Patch0:         deja-dup-monitor_check_for_gtk.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-root
BuildRequires:  fdupes
# Required for PATCH0
BuildRequires:  gnome-common
BuildRequires:  gnome-doc-utils-devel
%if 0%{?sles_version} >= 11 
BuildRequires:	gconf2-devel
BuildRequires:	gnome-keyring-devel
BuildRequires:	gtk2-devel
BuildRequires:	nautilus-devel
BuildRequires:	libnotify-devel
BuildRequires:	libunique-devel
%else
BuildRequires:  pkgconfig(gconf-2.0)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(libnautilus-extension)
# This would be an additional Option for deja-dup
#BuildRequires:  pkgconfig(appindicator-0.1)
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(unique-1.0)
BuildRequires:	vala
%endif
BuildRequires:  update-desktop-files
Requires:       duplicity
Recommends:     %{name}-lang
%gconf_schemas_prereq

%description
Déjà  Dup is a simple backup tool. It hides the complexity of doing
backups the 'right way' (encrypted, off-site, and regular) and uses
duplicity as the backend.

Features:
 * Support for local or remote backup locations, including Amazon S3
 * Securely encrypts and compresses your data
 * Incrementally backs up, letting you restore from any particular backup
 * Schedules regular backups
 * Integrates well into your GNOME desktop

%package -n nautilus-deja-dup
License:        GPLv3+
Summary:        Déjà Dup Plugin for Nautilus
Group:          Productivity/Archiving/Backup
Requires:       %{name} = %{version}
Supplements:    packageand(%{name}:nautilus}

%description -n nautilus-deja-dup
Déjà  Dup is a simple backup tool. It hides the complexity of doing
backups the 'right way' (encrypted, off-site, and regular) and uses
duplicity as the backend.

Features:
 * Support for local or remote backup locations, including Amazon S3
 * Securely encrypts and compresses your data
 * Incrementally backs up, letting you restore from any particular backup
 * Schedules regular backups
 * Integrates well into your GNOME desktop

This package contains a plugin to integrate Déjà Dup into Nautilus.

%lang_package
%prep
%setup -q
%patch0

%build
#NOCONFIGURE=1 gnome-autogen.sh
%configure --disable-static \
        --disable-schemas-install \
        --without-gtk3
%__make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install
find %{buildroot} -type f -name "*.la" -delete -print
%suse_update_desktop_file deja-dup
%suse_update_desktop_file deja-dup-monitor
%find_lang %{name} %{?no_lang_C}
# Localized man pages
for man in %{buildroot}%{_mandir}/*/man1/*; do
    LOCALE=`echo $man | sed "s:.*%{_mandir}/\([^/]*\)/man1/.*:\1:g"`
    echo "%%lang($LOCALE) %%dir %%{_mandir}/$LOCALE" >> %{name}.man-lang
    echo "%%lang($LOCALE) %%dir %%{_mandir}/$LOCALE/man1" >> %{name}.man-lang
    echo "%%lang($LOCALE) %%doc ${man##%{buildroot}}*" >> %{name}.man-lang
done
# create symlinks for man pages
%fdupes -s %{buildroot}%{_mandir}
# create hardlinks for the rest
%fdupes %{buildroot}
%find_gconf_schemas

%clean
rm -rf %{buildroot}

%pre -f %{name}.schemas_pre

%posttrans -f %{name}.schemas_posttrans

%preun -f %{name}.schemas_preun

%if 0%{?suse_version} > 1130

%post
%desktop_database_post
%icon_theme_cache_post
%endif

%if 0%{?suse_version} > 1130

%postun
%desktop_database_postun
%icon_theme_cache_postun
%endif

%files -f %{name}.schemas_list -f %{name}.man-lang
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%{_sysconfdir}/gconf/schemas/deja-dup.schemas
%{_bindir}/deja-dup
%{_bindir}/deja-dup-preferences
%{_mandir}/man1/deja-dup.*
%{_mandir}/man1/deja-dup-preferences.*
%{_sysconfdir}/xdg/autostart/deja-dup-monitor.desktop
# We explicitly list the content of %%{_libdir}/deja-dup to make sure we put
# the files in the right subpackage
%dir %{_libdir}/deja-dup
%{_libdir}/deja-dup/deja-dup-monitor
%{_datadir}/applications/deja-dup.desktop
#%{_datadir}/applications/deja-dup-preferences.desktop
%{_datadir}/icons/hicolor/scalable/actions/deja-dup-backup.svg
%{_datadir}/icons/hicolor/scalable/actions/deja-dup-restore.svg
%{_datadir}/icons/hicolor/scalable/apps/deja-dup.svg
%{_datadir}/icons/hicolor/scalable/apps/deja-dup-symbolic.svg

%files -n nautilus-deja-dup
%defattr(-,root,root)
%{_libdir}/nautilus/extensions-2.0/libnautilus-deja-dup.so

%files lang -f %{name}.lang

%changelog
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
  + %%icon_theme_cache_post/postun because the package ships themed
    icons.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
- Change Requires of lang subpackage to Recommends, since the
  english documentation is not there anymore.
* Tue Dec 14 2010 vuntz@opensuse.org
- Own directories of localized man pages to fix build. Also move
  those files to the main package: they should eventually live in
  the lang subpackage, but at the moment, they would create a file
  conflict between bundles and the lang subpackage.
- Own %%{_libdir}/deja-dup.
* Sat Nov 20 2010 badshah400@gmail.com
- Update to version 16.1.1:
  + Bug fixes: Fix help documentation translations
- Changes in version 16.1:
  + Bug fixes:
  - If backup destination does not report free size,
    just continue anyway
  - Fix bug preventing sudo and encryption getting along
  - Don't ask for root password when restoring into the user's
    home folder
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 16.0:
  + Updated translations.
* Sun Sep 12 2010 dimstar@opensuse.org
- Update to version 15.92:
  + Support ConnMan
  + Disable explicit resume support until bugs with it are fixed
  + Fix a bug where symlink excludes were actually included.
- Rebase deja-dup-monitor_check_for_gtk.patch.
- Handle new deja-dup-preferences.desktop.
* Thu Aug 12 2010 vuntz@opensuse.org
- Remove desktop-file-utils BuildRequires and change vala-devel
  BuildRequires to vala.
- Split a nautilus-deja-dup subpackage for the nautilus extension.
- Pass --without-gtk3 to configure to explicitly disable GTK+ 3 at
  the moment.
- Put localized man pages in the lang package.
* Wed Aug 11 2010 dimstar@opensuse.org
- Minor spec cleanups like trailing spaces and the like.
- Add gnome-common BuildRequires and use gnome-autogen.sh for the
  patch to re-bootstrap.
- Convert generic BuildRequires to pkgconfig() ones:
  + gconf2-devel => gconf-2.0
  + nautilus-devel => nautilus-extension
  + unique-devel => unique-1.0
  + libnotify-devel => libnotify
  + gnome-keyring-devel => gnome-keyring-1
- Drop un-needed BuildRequires: gettext, pango-devel, intltool,
  glib2-devel, cairo-devel, libtool.
- Use %%{?_smp_mflags} for parallel build.
* Wed Aug 11 2010 lmedinas@opensuse.org
- Initial import.
